==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/ar.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "الكتابة في مجلد \"config\" غير ممكنة!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "يمكن حل هذا عادة بإعطاء خادم الوب صلاحية الكتابة في مجلد config",
    "See %s" : "أنظر %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "يمكن إصلاح هذا الخطا بإعطاء مخدّم الموقع صلاحيات التعديل على مجلد الإعدادات. أنظر %s",
    "Sample configuration detected" : "تم اكتشاف إعدادات عيّنة",
    "%1$s and %2$s" : "%1$s و %2$s",
    "%1$s, %2$s and %3$s" : "%1$s، %2$s و %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s، %2$s، %3$s و %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s، %2$s، %3$s، %4$s و %5$s",
    "Education Edition" : "الإصدار التعليمي",
    "Enterprise bundle" : "حزمة المؤسسة",
    "PHP %s or higher is required." : "إصدار PHP %s أو أحدث منه مطلوب.",
    "PHP with a version lower than %s is required." : "PHP الإصدار %s أو أقل مطلوب.",
    "%sbit or higher PHP required." : "مكتبات PHP ذات %s بت أو أعلى مطلوبة.",
    "Following databases are supported: %s" : "قواعد البيانات التالية مدعومة: %s",
    "The command line tool %s could not be found" : "لم يتم العثور على أداة سطر الأوامر %s",
    "The library %s is not available." : "مكتبة %s غير متوفرة.",
    "Authentication" : "المصادقة",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "Avatar image is not square" : "الصورة الرمزية ليست على شكل مربّع",
    "today" : "اليوم",
    "tomorrow" : "غدًا",
    "yesterday" : "يوم أمس",
    "_%n day ago_::_%n days ago_" : ["قبل ساعات","قبل يوم","قبل يومين","قبل %n يوماً","قبل %n يوماً","قبل %n يوماً"],
    "next month" : "الشهر القادم",
    "last month" : "الشهر الماضي",
    "_%n month ago_::_%n months ago_" : ["قبل عدة أيام","قبل شهر","قبل شهرين","قبل %n شهراً","قبل %n شهراً","قبل %n شهراً"],
    "next year" : "العام القادم",
    "last year" : "السنةالماضية",
    "in a few seconds" : "خلال بضع ثواني",
    "seconds ago" : "منذ ثواني",
    "File name is a reserved word" : "اسم الملف كلمة محجوزة",
    "File name contains at least one invalid character" : "اسم الملف به ، على الأقل ، حرف غير صالح",
    "File name is too long" : "اسم الملف طويل جداً",
    "Empty filename is not allowed" : "لا يسمح بأسماء فارغة للملفات",
    "__language_name__" : "اللغة العربية",
    "Help" : "المساعدة",
    "Apps" : "التطبيقات",
    "Settings" : "الإعدادات",
    "Log out" : "الخروج",
    "Users" : "المستخدمين",
    "Unknown user" : "المستخدم غير معروف",
    "Overview" : "نظرة شاملة",
    "Basic settings" : "الإعدادات الأساسية",
    "Sharing" : "المشاركة",
    "Security" : "الأمان",
    "Additional settings" : "الإعدادات المتقدمة",
    "Personal info" : "المعلومات الشخصية",
    "%s enter the database username and name." : "%s أدخِل اسم قاعدة البيانات واسم مستخدمها.",
    "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
    "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
    "%s you may not use dots in the database name" : "%s لا يسمح لك باستخدام نقطه (.) في اسم قاعدة البيانات",
    "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "نظام ماك الإصدار X غير مدعوم و %s لن يعمل بشكل صحيح على هذه المنصة.  استخدمه على مسؤوليتك!",
    "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
    "Set an admin username." : "اعداد اسم مستخدم للمدير",
    "Set an admin password." : "اعداد كلمة مرور للمدير",
    "Can't create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في مجلد البيانات %s",
    "Invalid Federated Cloud ID" : "معرّف سحابة الاتحاد غير صالح",
    "You are not allowed to share %s" : "أنت غير مسموح لك أن تشارك %s",
    "Click the button below to open it." : "أنقر على الزر أدناه لفتحه.",
    "Could not find category \"%s\"" : "تعذر العثور على المجلد \"%s\"",
    "Sunday" : "الأحد",
    "Monday" : "الإثنين",
    "Tuesday" : "الثلاثاء",
    "Wednesday" : "الأربعاء",
    "Thursday" : "الخميس",
    "Friday" : "الجمعة",
    "Saturday" : "السبت",
    "Sun." : "أح.",
    "Mon." : "إث.",
    "Tue." : "ثلا.",
    "Wed." : "أر.",
    "Thu." : "خم.",
    "Fri." : "جم.",
    "Sat." : "سب.",
    "Su" : "أح",
    "Mo" : "إث",
    "Tu" : "ثلا",
    "We" : "أر",
    "Th" : "خم",
    "Fr" : "جم",
    "Sa" : "سب",
    "January" : "جانفي",
    "February" : "فيفري",
    "March" : "مارس",
    "April" : "أفريل",
    "May" : "ماي",
    "June" : "جوان",
    "July" : "جويلية",
    "August" : "أوت",
    "September" : "سبتمبر",
    "October" : "أكتوبر",
    "November" : "نوفمبر",
    "December" : "ديسمبر",
    "Jan." : "جان.",
    "Feb." : "فيف.",
    "Mar." : "مار.",
    "Apr." : "أفر.",
    "May." : "ماي",
    "Jun." : "جوا.",
    "Jul." : "جوي.",
    "Aug." : "أوت",
    "Sep." : "سبت.",
    "Oct." : "أكت.",
    "Nov." : "نوف.",
    "Dec." : "ديس.",
    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
    "Username contains whitespace at the beginning or at the end" : "إنّ إسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
    "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
    "Could not create user" : "لا يمكن إنشاء المستخدم",
    "User disabled" : "المستخدم معطّل",
    "Login canceled by app" : "تم إلغاء الدخول مِن طرف التطبيق",
    "a safe home for all your data" : "المكان الآمن لجميع بياناتك",
    "File is currently busy, please try again later" : "إنّ الملف مشغول الآمن، يرجى إعادة المحاولة لاحقًا",
    "Can't read file" : "لا يمكن قراءة الملف",
    "Application is not enabled" : "التطبيق غير مفعّل",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
    "Delete" : "حذف",
    "Unlimited" : "غير محدود",
    "Verifying" : "التحقق",
    "Verifying …" : "عملية التحقق جارية …",
    "Verify" : "التحقق",
    "Sharing %s failed, because the file does not exist" : "فشلت مشاركة %s فالملف غير موجود",
    "Sharing %s failed, because you can not share with yourself" : "فشلت مشاركة %s لأنك لايمكنك المشاركة مع نفسك",
    "Sharing %s failed, because the user %s does not exist" : "فشلت مشاركة %s لأن المستخدم %s غير موجود",
    "Share type %s is not valid for %s" : "مشاركة النوع %s غير صالحة لـ %s",
    "%s shared »%s« with you" : "%s شارك »%s« معك",
    "%s via %s" : "%s عبر %s"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/ar.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "الكتابة في مجلد \"config\" غير ممكنة!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "يمكن حل هذا عادة بإعطاء خادم الوب صلاحية الكتابة في مجلد config",
    "See %s" : "أنظر %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "يمكن إصلاح هذا الخطا بإعطاء مخدّم الموقع صلاحيات التعديل على مجلد الإعدادات. أنظر %s",
    "Sample configuration detected" : "تم اكتشاف إعدادات عيّنة",
    "%1$s and %2$s" : "%1$s و %2$s",
    "%1$s, %2$s and %3$s" : "%1$s، %2$s و %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s، %2$s، %3$s و %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s، %2$s، %3$s، %4$s و %5$s",
    "Education Edition" : "الإصدار التعليمي",
    "Enterprise bundle" : "حزمة المؤسسة",
    "PHP %s or higher is required." : "إصدار PHP %s أو أحدث منه مطلوب.",
    "PHP with a version lower than %s is required." : "PHP الإصدار %s أو أقل مطلوب.",
    "%sbit or higher PHP required." : "مكتبات PHP ذات %s بت أو أعلى مطلوبة.",
    "Following databases are supported: %s" : "قواعد البيانات التالية مدعومة: %s",
    "The command line tool %s could not be found" : "لم يتم العثور على أداة سطر الأوامر %s",
    "The library %s is not available." : "مكتبة %s غير متوفرة.",
    "Authentication" : "المصادقة",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "Avatar image is not square" : "الصورة الرمزية ليست على شكل مربّع",
    "today" : "اليوم",
    "tomorrow" : "غدًا",
    "yesterday" : "يوم أمس",
    "_%n day ago_::_%n days ago_" : ["قبل ساعات","قبل يوم","قبل يومين","قبل %n يوماً","قبل %n يوماً","قبل %n يوماً"],
    "next month" : "الشهر القادم",
    "last month" : "الشهر الماضي",
    "_%n month ago_::_%n months ago_" : ["قبل عدة أيام","قبل شهر","قبل شهرين","قبل %n شهراً","قبل %n شهراً","قبل %n شهراً"],
    "next year" : "العام القادم",
    "last year" : "السنةالماضية",
    "in a few seconds" : "خلال بضع ثواني",
    "seconds ago" : "منذ ثواني",
    "File name is a reserved word" : "اسم الملف كلمة محجوزة",
    "File name contains at least one invalid character" : "اسم الملف به ، على الأقل ، حرف غير صالح",
    "File name is too long" : "اسم الملف طويل جداً",
    "Empty filename is not allowed" : "لا يسمح بأسماء فارغة للملفات",
    "__language_name__" : "اللغة العربية",
    "Help" : "المساعدة",
    "Apps" : "التطبيقات",
    "Settings" : "الإعدادات",
    "Log out" : "الخروج",
    "Users" : "المستخدمين",
    "Unknown user" : "المستخدم غير معروف",
    "Overview" : "نظرة شاملة",
    "Basic settings" : "الإعدادات الأساسية",
    "Sharing" : "المشاركة",
    "Security" : "الأمان",
    "Additional settings" : "الإعدادات المتقدمة",
    "Personal info" : "المعلومات الشخصية",
    "%s enter the database username and name." : "%s أدخِل اسم قاعدة البيانات واسم مستخدمها.",
    "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
    "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
    "%s you may not use dots in the database name" : "%s لا يسمح لك باستخدام نقطه (.) في اسم قاعدة البيانات",
    "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "نظام ماك الإصدار X غير مدعوم و %s لن يعمل بشكل صحيح على هذه المنصة.  استخدمه على مسؤوليتك!",
    "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
    "Set an admin username." : "اعداد اسم مستخدم للمدير",
    "Set an admin password." : "اعداد كلمة مرور للمدير",
    "Can't create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في مجلد البيانات %s",
    "Invalid Federated Cloud ID" : "معرّف سحابة الاتحاد غير صالح",
    "You are not allowed to share %s" : "أنت غير مسموح لك أن تشارك %s",
    "Click the button below to open it." : "أنقر على الزر أدناه لفتحه.",
    "Could not find category \"%s\"" : "تعذر العثور على المجلد \"%s\"",
    "Sunday" : "الأحد",
    "Monday" : "الإثنين",
    "Tuesday" : "الثلاثاء",
    "Wednesday" : "الأربعاء",
    "Thursday" : "الخميس",
    "Friday" : "الجمعة",
    "Saturday" : "السبت",
    "Sun." : "أح.",
    "Mon." : "إث.",
    "Tue." : "ثلا.",
    "Wed." : "أر.",
    "Thu." : "خم.",
    "Fri." : "جم.",
    "Sat." : "سب.",
    "Su" : "أح",
    "Mo" : "إث",
    "Tu" : "ثلا",
    "We" : "أر",
    "Th" : "خم",
    "Fr" : "جم",
    "Sa" : "سب",
    "January" : "جانفي",
    "February" : "فيفري",
    "March" : "مارس",
    "April" : "أفريل",
    "May" : "ماي",
    "June" : "جوان",
    "July" : "جويلية",
    "August" : "أوت",
    "September" : "سبتمبر",
    "October" : "أكتوبر",
    "November" : "نوفمبر",
    "December" : "ديسمبر",
    "Jan." : "جان.",
    "Feb." : "فيف.",
    "Mar." : "مار.",
    "Apr." : "أفر.",
    "May." : "ماي",
    "Jun." : "جوا.",
    "Jul." : "جوي.",
    "Aug." : "أوت",
    "Sep." : "سبت.",
    "Oct." : "أكت.",
    "Nov." : "نوف.",
    "Dec." : "ديس.",
    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
    "Username contains whitespace at the beginning or at the end" : "إنّ إسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
    "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
    "Could not create user" : "لا يمكن إنشاء المستخدم",
    "User disabled" : "المستخدم معطّل",
    "Login canceled by app" : "تم إلغاء الدخول مِن طرف التطبيق",
    "a safe home for all your data" : "المكان الآمن لجميع بياناتك",
    "File is currently busy, please try again later" : "إنّ الملف مشغول الآمن، يرجى إعادة المحاولة لاحقًا",
    "Can't read file" : "لا يمكن قراءة الملف",
    "Application is not enabled" : "التطبيق غير مفعّل",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
    "Create" : "إنشاء",
    "Delete" : "حذف",
    "Share" : "شارك",
    "Unlimited" : "غير محدود",
    "Verifying" : "التحقق",
    "Verifying …" : "عملية التحقق جارية …",
    "Verify" : "التحقق",
    "Sharing %s failed, because the file does not exist" : "فشلت مشاركة %s فالملف غير موجود",
    "Sharing %s failed, because you can not share with yourself" : "فشلت مشاركة %s لأنك لايمكنك المشاركة مع نفسك"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
